@@ -193,6 +193,6 @@ def batch_encode_plus(tokenizer, examples, max_length, progress_bar=False):
         for key, value in batch_encoding.items():
             if key not in batch_outputs:
                 batch_outputs[key] = []
-            batch_outputs[key].append(value)
+            batch_outputs[key].extend(value)
 
     return BatchEncoding(batch_outputs)
